/* gInfo - Copyright (C) 2004 bakunin - Andrea Marchesini 
 *                                      <bakunin@autistici.org>
 *
 * This source code is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Public License as published 
 * by the Free Software Foundation; either version 2 of the License,
 * or (at your option) any later version.
 *
 * This source code is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * Please refer to the GNU Public License for more details.
 *
 * You should have received a copy of the GNU Public License along with
 * this source code; if not, write to:
 * Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#else
# error Use configure; make; make install
#endif

#include "ginfo.h"
#include "confuse/confuse.h"

int config_init (void);

void
config_read (void)
{
  char *home;
  char *t;
  int n;
  cfg_t *cfg;

  cfg_opt_t opts[] = {
    CFG_BOOL ("tooltips", cfg_false, CFGF_NONE),
    CFG_STR ("border_color", "#614CAB", CFGF_NONE),
    CFG_END ()
  };

  if (config_init ())
    return;

  if (!(home = getenv ("HOME")))
    {
      msg ("No HOME enviroment. I can't read your configuration.");
      return;
    }

  n = strlen (home) + 20;
  if (!(t = (char *) malloc (sizeof (char) * n)))
    fatal ("Error: memory.");

  snprintf (t, n, "%s/.ginfo.cfg", home);

  cfg = cfg_init (opts, CFGF_NOCASE);

  switch (cfg_parse (cfg, t))
    {
    case CFG_FILE_ERROR:
      msg ("I can't read yout configuration.");
      free (t);
      return;
    case CFG_PARSE_ERROR:
      msg ("I can't read yout configuration.");
      unlink (t);
      free (t);
      return;
    }

  tooltip_done = cfg_getbool (cfg, "tooltips");
  graphic_color = strdup (cfg_getstr (cfg, "border_color"));

  cfg_free (cfg);

  free (t);
}


void
config_write (void)
{
  int n;
  FILE *fl;
  char *home, *t;

  if (!(home = getenv ("HOME")))
    {
      msg ("No HOME enviroment. I can't initialize your configuration.");
      return;
    }

  n = strlen (home) + 20;
  if (!(t = (char *) malloc (sizeof (char *) * n)))
    fatal ("Error: memory.");

  snprintf (t, n, "%s/.ginfo.cfg", home);

  if (!(fl = fopen (t, "w")))
    {
      msg ("I can't write your configuration.");
      free (t);
      return;
    }

  fprintf (fl, "tooltips = %s\n", tooltip_done ? "true" : "false");
  fprintf (fl, "border_color = \"%s\"\n", graphic_color);

  fclose (fl);
}

int
config_init (void)
{
  char *home;
  char *t;
  int n;
  struct stat st;
  FILE *fl;

  if (!(home = getenv ("HOME")))
    {
      msg ("No HOME enviroment. I can't initialize your configuration.");
      return 1;
    }

  n = strlen (home) + 20;
  if (!(t = (char *) malloc (sizeof (char) * n)))
    fatal ("Error: memory.");

  snprintf (t, n, "%s/.ginfo.cfg", home);

  if (lstat (t, &st))
    {
      if (!(fl = fopen (t, "w")))
	{
	  free (t);
	  return 1;
	}

      fprintf (fl, "tooltips = false\n");
      fprintf (fl, "border_color = \"#614CAB\"\n");

      fclose (fl);
    }

  free (t);

  return 0;
}

/* EOF */
