/* gInfo - Copyright (C) 2004 bakunin - Andrea Marchesini 
 *                                      <bakunin@autistici.org>
 *
 * This source code is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Public License as published 
 * by the Free Software Foundation; either version 2 of the License,
 * or (at your option) any later version.
 *
 * This source code is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * Please refer to the GNU Public License for more details.
 *
 * You should have received a copy of the GNU Public License along with
 * this source code; if not, write to:
 * Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#else
# error Use configure; make; make install
#endif

#include "ginfo.h"
#include "ginfo_logo_s.xpm"

GtkWidget *mainwin;
GtkWidget *graphic_menu;
GtkWidget *graphic_frame;
char *graphic_color = NULL;
char *graphic_image = NULL;

void graphic_get_coord (GtkWidget *, int *, int *);
gint graphic_starter (GtkWidget *, GdkEventButton *);
GtkWidget *graphic_create_menu (void);

void
graphic_init (void)
{
  GdkColor color;
  GdkPixmap *pixmap;
  GdkPixmap *mask;
  GtkWidget *image = NULL;
  GtkWidget *button;
  int x, y;

  graphic_menu = graphic_create_menu ();

  mainwin = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_window_set_title (GTK_WINDOW (mainwin), PACKAGE);
  gtk_widget_set_app_paintable (mainwin, TRUE);
  gtk_window_set_policy (GTK_WINDOW (mainwin), FALSE, FALSE, TRUE);

  gtk_widget_realize (mainwin);
  gdk_window_set_decorations (mainwin->window, 0);

  if (!graphic_color)
    graphic_color = strdup ("#614CAB");
  gdk_color_parse (graphic_color, &color);

  graphic_frame = gtk_frame_new (NULL);
  gtk_widget_show (graphic_frame);
  gtk_container_add (GTK_CONTAINER (mainwin), graphic_frame);
  gtk_frame_set_shadow_type (GTK_FRAME (graphic_frame),
			     GTK_SHADOW_ETCHED_OUT);
  gtk_widget_modify_bg (graphic_frame, GTK_STATE_NORMAL, &color);

  button = gtk_button_new ();
  gtk_button_set_relief (GTK_BUTTON (button), GTK_RELIEF_NONE);
  gtk_widget_show (button);
  gtk_container_add (GTK_CONTAINER (graphic_frame), button);

  if (graphic_image)
    {
      if (!(image = gtk_image_new_from_file (graphic_image)))
	msg ("Could not find image %s.", graphic_image);
    }

  if (!image)
    {
      pixmap = gdk_pixmap_create_from_xpm_d (mainwin->window, &mask, NULL,
					     ginfo_logo_s);
      image = gtk_image_new_from_pixmap (pixmap, mask);
    }

  gtk_widget_show (image);
  gtk_container_add (GTK_CONTAINER (button), image);

  graphic_get_coord (mainwin, &x, &y);
  gtk_widget_set_uposition (mainwin, x, y);
  gtk_widget_show (mainwin);

  g_signal_connect ((gpointer) mainwin, "destroy", G_CALLBACK (gtk_main_quit),
		    NULL);
  g_signal_connect ((gpointer) mainwin, "delete_event",
		    G_CALLBACK (gtk_main_quit), NULL);
  gtk_signal_connect_object (GTK_OBJECT (button), "button_press_event",
			     G_CALLBACK (graphic_starter), NULL);

}

gint
graphic_starter (GtkWidget * w, GdkEventButton * event)
{
  if (event->button == 3)
    {
      GdkEventButton *bevent = (GdkEventButton *) event;

      gtk_menu_popup (GTK_MENU (graphic_menu), NULL, NULL, NULL, NULL,
		      bevent->button, bevent->time);

      return TRUE;
    }
  else if (event->type == GDK_BUTTON_PRESS)
    {
      if (!tutor_win)
	{
	  tutor_init ();
	  tutor_container (tutor_container_default, NULL);
	}
      else
	tutor_init ();
    }

  return FALSE;
}

void
graphic_get_coord (GtkWidget * w, int *x, int *y)
{
  GtkRequisition requisition;

  gtk_widget_size_request (GTK_WIDGET (w), &requisition);
  *x = (gdk_screen_width () - requisition.width) / 2;
  *y = 0;			//gdk_screen_height () - requisition.height;
  if (*x < 0)
    *x = 0;
  /*
     if (*y < 0)
     *y = 0;
   */
}

GtkWidget *
graphic_create_menu (void)
{
  GtkWidget *menu;
  GtkWidget *nt;
  GtkWidget *pref;
  GtkWidget *modules;
  GtkWidget *about;
  GtkWidget *separator;
  GtkWidget *editor;
  GtkWidget *quit;

  menu = gtk_menu_new ();

  nt = gtk_menu_item_new_with_mnemonic ("_New Tips!");
  gtk_widget_show (nt);
  gtk_container_add (GTK_CONTAINER (menu), nt);

  g_signal_connect ((gpointer) nt, "activate", G_CALLBACK (menu_nt), NULL);

  pref = gtk_menu_item_new_with_mnemonic ("_Preference");
  gtk_widget_show (pref);
  gtk_container_add (GTK_CONTAINER (menu), pref);

  g_signal_connect ((gpointer) pref, "activate", G_CALLBACK (menu_preference),
		    NULL);

  modules = gtk_menu_item_new_with_mnemonic ("_Modules");
  gtk_widget_show (modules);
  gtk_container_add (GTK_CONTAINER (menu), modules);

  g_signal_connect ((gpointer) modules, "activate", G_CALLBACK (menu_modules),
		    NULL);

  about = gtk_menu_item_new_with_mnemonic ("_About");
  gtk_widget_show (about);
  gtk_container_add (GTK_CONTAINER (menu), about);

  g_signal_connect ((gpointer) about, "activate", G_CALLBACK (menu_about),
		    NULL);

  separator = gtk_menu_item_new ();
  gtk_widget_show (separator);
  gtk_container_add (GTK_CONTAINER (menu), separator);
  gtk_widget_set_sensitive (separator, FALSE);

  editor = gtk_menu_item_new_with_mnemonic ("gInfo _Editor");
  gtk_widget_show (editor);
  gtk_container_add (GTK_CONTAINER (menu), editor);

  g_signal_connect ((gpointer) editor, "activate", G_CALLBACK (menu_editor),
		    NULL);

  separator = gtk_menu_item_new ();
  gtk_widget_show (separator);
  gtk_container_add (GTK_CONTAINER (menu), separator);
  gtk_widget_set_sensitive (separator, FALSE);

  quit = gtk_menu_item_new_with_mnemonic ("_Quit");
  gtk_widget_show (quit);
  gtk_container_add (GTK_CONTAINER (menu), quit);

  g_signal_connect ((gpointer) quit, "activate", G_CALLBACK (menu_quit),
		    NULL);

  return menu;
}

/* EOF */
